package css_printer
import "github.com/evanw/esbuild/internal/css_printer"
Index ¶
Types ¶
type Options ¶
type Options struct {
// This will be present if the input file had a source map. In that case we
// want to map all the way back to the original input file(s).
InputSourceMap *sourcemap.SourceMap
// If we're writing out a source map, this table of line start indices lets
// us do binary search on to figure out what line a given AST node came from
LineOffsetTables []sourcemap.LineOffsetTable
// Local symbol renaming results go here
LocalNames map[ast.Ref]string
LineLimit int
InputSourceIndex uint32
UnsupportedFeatures compat.CSSFeature
MinifyWhitespace bool
ASCIIOnly bool
SourceMap config.SourceMap
AddSourceMappings bool
LegalComments config.LegalComments
NeedsMetafile bool
}
type PrintResult ¶
type PrintResult struct {
CSS []byte
ExtractedLegalComments []string
JSONMetadataImports []string
// This source map chunk just contains the VLQ-encoded offsets for the "CSS"
// field above. It's not a full source map. The bundler will be joining many
// source map chunks together to form the final source map.
SourceMapChunk sourcemap.Chunk
}
func Print ¶
Source Files ¶
- Version
- v0.25.8 (latest)
- Published
- Jul 19, 2025
- Platform
- linux/amd64
- Imports
- 11 packages
- Last checked
- 8 months ago –
Tools for package owners.